<?php
/**
 * Shopay functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Shopay
 */

if ( ! defined( 'shopay_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	$shopay_blog_theme_info = wp_get_theme();
	define( 'shopay_VERSION', $shopay_blog_theme_info->get( 'Version' ) );
}

if ( ! function_exists( 'shopay_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function shopay_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Shopay, use a find and replace
		 * to change 'shopay' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'shopay', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-top' 		=> esc_html__( 'Top Menu', 'shopay' ),
			'menu-primary' 	=> esc_html__( 'Primary Menu', 'shopay' ),
			'menu-footer' 	=> esc_html__( 'Footer Menu', 'shopay' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'shopay_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		add_theme_support( 'starter-content', array(
				'theme_mods' =>  array(
					'shopay_top_header_option'		=> true,
					'shopay_top_header_description' => __( 'Welcome To Worldwide Store', 'shopay' ),
					'shopay_top_header_location'	=> __( 'Store Locator', 'shopay' ),
					'shopay_top_header_service'		=> __( 'Free Delivery', 'shopay' ),
					'shopay_site_info_option'		=> true,
					'shopay_header_site_contact_info' => __( 'Support ( +123-465465464)', 'shopay' ),
					'shopay_header_site_email_info' => __( 'Email: noreply@example.com', 'shopay' )
				)
			)
		);

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
        
        /**
	     * Restoring the classic Widgets Editor
	     * 
	     * @since 1.1.5
	     */
	    $shopay_enable_widgets_editor = get_theme_mod( 'shopay_enable_widgets_editor', false );
		if ( false === $shopay_enable_widgets_editor ) {
			remove_theme_support( 'widgets-block-editor' );
		}
	}
endif;
add_action( 'after_setup_theme', 'shopay_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function shopay_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'shopay_content_width', 640 );
}
add_action( 'after_setup_theme', 'shopay_content_width', 0 );

/**
 * Set the theme version, based on theme stylesheet.
 *
 * @global string $shopay_theme_version
 */
function shopay_theme_version_info() {
	$shopay_theme_info = wp_get_theme();
	$GLOBALS['shopay_theme_version'] = $shopay_theme_info->get( 'Version' );
}
add_action( 'after_setup_theme', 'shopay_theme_version_info', 5 );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Widgets function.
 */
require get_template_directory() . '/inc/widgets/widgets-functions.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( shopay_is_active_woocommerce() ) {
	require get_template_directory() . '/inc/woocommerce/woocommerce.php';
	require get_template_directory() . '/inc/woocommerce/woocommerce-functions.php';
}

/**
* Load theme dashboard
*/
require get_template_directory() . '/inc/admin/class-shopay-admin.php';
require get_template_directory() . '/inc/admin/class-shopay-notice.php';
require get_template_directory() . '/inc/admin/class-shopay-dashboard.php';